==> deadnews_template_python-2.0.6.tar.gz: deadnews_template_python-2.0.6/README.md <==
<div align="center">

# deadnews-template-python

Python Project Template

[![PyPI: Version](https://img.shields.io/pypi/v/deadnews-template-python?logo=pypi&logoColor=white)](https://pypi.org/project/deadnews-template-python)
[![GitHub: Release](https://img.shields.io/github/v/release/deadnews/deadnews-template-python?logo=github&logoColor=white)](https://github.com/deadnews/deadnews-template-python/releases/latest)
[![Docker: ghcr](https://img.shields.io/badge/docker-ghcr-blue.svg?logo=github&logoColor=white)](https://github.com/deadnews/deadnews-template-python/pkgs/container/deadnews-template-python)
[![Docker: image-size](https://ghcr-badge.egpl.dev/deadnews/deadnews-template-python/size?color=%230e80c0)](https://github.com/deadnews/deadnews-template-python/pkgs/container/deadnews-template-python)
\
[![Documentation](https://img.shields.io/badge/documentation-gray.svg?logo=materialformkdocs&logoColor=white)](https://deadnews.github.io/deadnews-template-python)
[![Changelog](https://img.shields.io/badge/changelog-gray.svg?logo=github&logoColor=white)](https://github.com/deadnews/deadnews-template-python/blob/main/CHANGELOG.md)
\
[![CI: main](https://img.shields.io/github/actions/workflow/status/deadnews/deadnews-template-python/main.yml?branch=main&logo=github&logoColor=white&label=main)](https://github.com/deadnews/deadnews-template-python/actions/workflows/main.yml)
[![CI: pre-commit](https://results.pre-commit.ci/badge/github/DeadNews/deadnews-template-python/main.svg)](https://results.pre-commit.ci/latest/github/deadnews/deadnews-template-python/main)
[![Coverage](https://img.shields.io/codecov/c/github/deadnews/deadnews-template-python?token=OCZDZIYPMC&logo=codecov&logoColor=white)](https://codecov.io/gh/deadnews/deadnews-template-python)

</div>

## Installation

PyPI

```sh
pip install deadnews-template-python
# or
pipx install deadnews-template-python
```

Docker

```sh
docker pull ghcr.io/deadnews/deadnews-template-python:latest
```

==> deadnews_template_python-2.0.7.tar.gz: deadnews_template_python-2.0.7/README.md <==
# deadnews-template-python

> Python Project Template

[![PyPI: Version](https://img.shields.io/pypi/v/deadnews-template-python?logo=pypi&logoColor=white)](https://pypi.org/project/deadnews-template-python)
[![GitHub: Release](https://img.shields.io/github/v/release/deadnews/deadnews-template-python?logo=github&logoColor=white)](https://github.com/deadnews/deadnews-template-python/releases/latest)
[![Docker: ghcr](https://img.shields.io/badge/docker-ghcr-blue.svg?logo=github&logoColor=white)](https://github.com/deadnews/deadnews-template-python/pkgs/container/deadnews-template-python)
[![Documentation](https://img.shields.io/badge/documentation-gray.svg?logo=materialformkdocs&logoColor=white)](https://deadnews.github.io/deadnews-template-python)
[![CI: pre-commit](https://results.pre-commit.ci/badge/github/DeadNews/deadnews-template-python/main.svg)](https://results.pre-commit.ci/latest/github/deadnews/deadnews-template-python/main)
[![CI: main](https://img.shields.io/github/actions/workflow/status/deadnews/deadnews-template-python/main.yml?branch=main&logo=github&logoColor=white&label=main)](https://github.com/deadnews/deadnews-template-python/actions/workflows/main.yml)
[![CI: coverage](https://img.shields.io/codecov/c/github/deadnews/deadnews-template-python?token=OCZDZIYPMC&logo=codecov&logoColor=white)](https://app.codecov.io/gh/deadnews/deadnews-template-python)

## Installation

PyPI

```sh
pip install deadnews-template-python
# or
pipx install deadnews-template-python
```

Docker

```sh
docker pull ghcr.io/deadnews/deadnews-template-python:latest
# or
docker pull ghcr.io/deadnews/deadnews-template-python:latest-pypy
```
